caliber
#######

.. image:: https://img.shields.io/pypi/status/caliber
    :target: https://img.shields.io/pypi/status/caliber
    :alt: PyPI - Status
.. image:: https://img.shields.io/pypi/dm/caliber
    :target: https://pypistats.org/packages/caliber
    :alt: PyPI - Downloads
.. image:: https://img.shields.io/pypi/v/caliber
    :target: https://img.shields.io/pypi/v/caliber
    :alt: PyPI - Version
.. image:: https://img.shields.io/github/license/gianlucadetommaso/caliber
    :target: https://github.com/gianlucadetommaso/caliber/blob/main/LICENSE
    :alt: License
.. image:: https://readthedocs.org/projects/caliber/badge/?version=latest
    :target: https://caliber.readthedocs.io
    :alt: Documentation Status

Caliber is a toolkit designed to enhance the calibration and overall performance
of your machine learning models.
It operates independently of your specific models,
offering a flexible and agnostic approach.
Caliber's methods are lightweight and generally fast,
making them easy to integrate as add-ons within your existing pipeline with minimal effort.

Installation
============
You can install caliber via

.. code-block::

    pip install caliber

The following extras are available:

- :code:`torch`: install `PyTorch <https://pytorch.org/>`_ dependencies.
- :code:`docs`: install `Sphinx <https://www.sphinx-doc.org/en/master/>`_ dependencies.

Alternatively, you can build the package using `Poetry <https://python-poetry.org/>`_.

License
=======
This project is licensed under the Apache-2.0 License.
